@@ -4,19 +4,22 @@ import { Menu, Widget } from '@lumino/widgets';
 import { Dialog, showDialog } from '@jupyterlab/apputils';
 import { INotebookTracker, NotebookPanel,   } from '@jupyterlab/notebook';
 import { IDocumentManager } from '@jupyterlab/docmanager';
-import { show_spinner } from '../dialog';
-import { getLabFilePath, loadLabContents, parseJwt } from '../tools';
-import { axiosHandler } from '../handler';
-import { Globals } from '../config';
+import { show_spinner, showFailureImportLabDialog } from '../dialog';
+import { getLabFileName, loadLabContents } from '../tools';
+import { axiosHandler, getLabModel } from '../handler';
+import * as nbformat from '@jupyterlab/nbformat';
+import { Globals, MODE } from '../config';
 
 export const menu: JupyterFrontEndPlugin<void> = {
   id: 'skillsnetwork-authoring-extension:menu',
   autoStart: true,
   requires: [IMainMenu, INotebookTracker, IDocumentManager],
-  activate: (app: JupyterFrontEnd, mainMenu: IMainMenu, notebookTracker: INotebookTracker, docManager: IDocumentManager) => {
+  activate: async (app: JupyterFrontEnd, mainMenu: IMainMenu, notebookTracker: INotebookTracker, docManager: IDocumentManager) => {
 
     console.log('Activated skillsnetwork-authoring-extension menu plugin!');
 
+    if (await MODE() == "learn") return
+
     const editLabFromToken = 'edit-lab-from-token';
     app.commands.addCommand(editLabFromToken, {
     label: 'Edit a Lab',
@@ -58,19 +61,25 @@ export const menu: JupyterFrontEndPlugin<void> = {
           show_spinner('Loading up your lab...');
 
           const token = tokenInput.value
-          const parsedToken = parseJwt(token)
-          const labFilename = getLabFilePath(parsedToken);
+          let {instructions_file_path, body: instructions_content} = await getLabModel(axiosHandler(token))
+          const labFilename = getLabFileName(instructions_file_path);
 
+          // Attempt to open the lab
           const nbPanel = docManager.createNew(labFilename, 'notebook', { name:  Globals.PY_KERNEL_NAME}) as NotebookPanel;
 
-          if (nbPanel === undefined){
+          if (nbPanel === undefined) {
             throw Error('Error loading lab')
           }
-          nbPanel.show();
-          await loadLabContents(nbPanel, axiosHandler(tokenInput.value));
+          loadLabContents(nbPanel, JSON.parse(instructions_content) as unknown as nbformat.INotebookContent);
+          Globals.TOKEN = tokenInput.value;
+          sessionStorage.setItem('atlas_token', Globals.TOKEN);
         }
       })
-      .catch();
+      .catch((e) => {
+        Dialog.flush(); //remove spinner
+        showFailureImportLabDialog();
+        console.log(e)
+      });
     };
   }
 };
