@@ -7,9 +7,6 @@ import {
 } from '@jupyterlab/notebook';
 import { DocumentRegistry } from '@jupyterlab/docregistry';
 import * as nbformat from '@jupyterlab/nbformat';
-import { getLabModel } from './handler';
-import { AxiosInstance } from 'axios';
-import { Buffer } from 'buffer';
 import { Globals } from './config';
 
 export interface ICellData {
@@ -75,44 +72,19 @@ export const getFileContents = (
   return JSON.stringify(rawFile, null, 2);
 };
 
-export const loadLabContents = async (widget: NotebookPanel, axiosHandlers: AxiosInstance, author_env?: string): Promise<void> => {
+export const loadLabContents = (widget: NotebookPanel, notebook_content : nbformat.INotebookContent, author_env?: string): void => {
   const model = new NotebookModel();
-  // Only try to load the initial lab notebook if the author is not coming from their local env
   if (author_env !== 'local'){
-    try {
-      const lab_model = (await getLabModel(
-        axiosHandlers
-      )) as unknown as nbformat.INotebookContent;
-      model.fromJSON(lab_model);
-    } catch {
-      throw 'Error getting lab model';
-    }
-    // testing purposes
-    //model.fromJSON(DEFAULT_CONTENT);
+    model.fromJSON(notebook_content);
   }
-  // testing purposes:
-  // model.fromJSON(DEFAULT_CONTENT);
   widget.content.model = model;
 };
 
-export const parseJwt = (token: string) => {
-  const base64Url = token.split('.')[1];
-  const base64 = base64Url.replace(/-/g, '+').replace(/_/g, '/');
-  // const decoded = atob(base64);
-  const decoded = Buffer.from(base64, 'base64').toString();
-  const jsonPayload = decodeURIComponent(decoded.split('').map(function(c) {
-      return '%' + ('00' + c.charCodeAt(0).toString(16)).slice(-2);
-  }).join(''));
-  return JSON.parse(jsonPayload);
-}
-
-export const getLabFilePath = (jwtparsed: any): string => {
-  let labFilename = jwtparsed.lab_filepath ?? Globals.DEFAULT_LAB_NAME;
-  // Replace labs/ prefix with empty string
-  // TODO: We need a more robust way to do this and not rely on the assumption that the lab is in the labs folder
+export const getLabFileName = (lab_filepath: any): string => {
+  let labFilePath = lab_filepath ?? Globals.DEFAULT_LAB_NAME;
+  // Extract filename from filepath
   // TODO: This is required as the createNew method will not automatically create the parent directories
-  labFilename = labFilename.replace('labs/', '');
-  return labFilename;
+  return labFilePath.replace(/^.*[\\\/]/, '');
 }
 
 // eslint-disable-next-line @typescript-eslint/quotes
